@@ -7,15 +7,16 @@
 #ifndef COMMON_DATABASE_H
 #define COMMON_DATABASE_H
 
-#include <utils/d_ptr.h>
-#include <memory>
-#include <QSqlQuery>
-#include <QRegExp>
 #include <QObject>
+#include <QRegExp>
+#include <QSqlQuery>
+#include <memory>
+#include <utils/d_ptr.h>
 
-namespace Common {
-
-class Database: public QObject {
+namespace Common
+{
+class Database : public QObject
+{
     Q_OBJECT
 
 public:
@@ -47,7 +48,8 @@ public:
     Database();
 
     friend class Locker;
-    class Locker {
+    class Locker
+    {
     public:
         explicit Locker(Database &database);
         ~Locker();
@@ -58,9 +60,9 @@ public:
 
     void reportError(const QSqlError &error);
 
-    #define DATABASE_TRANSACTION(A) \
-        /* enable this for debugging only: qCDebug(KAMD_LOG_RESOURCES) << "Location:" << __FILE__ << __LINE__; */ \
-        Common::Database::Locker lock(A)
+#define DATABASE_TRANSACTION(A)                                                                                                                                \
+    /* enable this for debugging only: qCDebug(KAMD_LOG_RESOURCES) << "Location:" << __FILE__ << __LINE__; */                                                  \
+    Common::Database::Locker lock(A)
 
 Q_SIGNALS:
     void error(const QSqlError &error) const;
@@ -69,24 +71,20 @@ private:
     D_PTR;
 };
 
-template <typename EscapeFunction>
-QString parseStarPattern(const QString &pattern, const QString &joker,
-                                   EscapeFunction escape)
+template<typename EscapeFunction>
+QString parseStarPattern(const QString &pattern, const QString &joker, EscapeFunction escape)
 {
-    const auto begin     = pattern.constBegin();
-    const auto end       = pattern.constEnd();
+    const auto begin = pattern.constBegin();
+    const auto end = pattern.constEnd();
 
-    auto currentStart    = pattern.constBegin();
+    auto currentStart = pattern.constBegin();
     auto currentPosition = pattern.constBegin();
 
     bool isEscaped = false;
 
     // This should be available in the QString class...
-    auto stringFromIterators = [&](const QString::const_iterator &currentStart,
-                                   const QString::const_iterator &currentPosition) {
-        return pattern.mid(
-                std::distance(begin, currentStart),
-                std::distance(currentStart, currentPosition));
+    auto stringFromIterators = [&](const QString::const_iterator &currentStart, const QString::const_iterator &currentPosition) {
+        return pattern.mid(std::distance(begin, currentStart), std::distance(currentStart, currentPosition));
     };
 
     // Escaping % and _ for sql like
@@ -108,8 +106,7 @@ QString parseStarPattern(const QString &pattern, const QString &joker,
 
         } else if (*currentPosition == QLatin1Char('*')) {
             // Replacing the star with the sql like joker - %
-            resultPattern.append(escape(stringFromIterators(
-                                    currentStart, currentPosition)) + joker);
+            resultPattern.append(escape(stringFromIterators(currentStart, currentPosition)) + joker);
             currentStart = currentPosition + 1;
 
         } else {
@@ -118,8 +115,7 @@ QString parseStarPattern(const QString &pattern, const QString &joker,
     }
 
     if (currentStart != currentPosition) {
-        resultPattern.append(escape(stringFromIterators(
-                                currentStart, currentPosition)));
+        resultPattern.append(escape(stringFromIterators(currentStart, currentPosition)));
     }
 
     return resultPattern;
@@ -143,4 +139,3 @@ inline QRegExp starPatternToRegex(const QString &pattern)
 } // namespace Common
 
 #endif // COMMON_DATABASE_H
-
